'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _configUtil = require('../utils/configUtil');

var _configUtil2 = _interopRequireDefault(_configUtil);

var _config = require('../../config.json');

var _config2 = _interopRequireDefault(_config);

var _constants = require('../constants.js');

var _constants2 = _interopRequireDefault(_constants);

var _winstonLogs = require('../utils/winstonLogs');

var _winstonLogs2 = _interopRequireDefault(_winstonLogs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var najax = require('najax');


var getFogControllerConfigs = function getFogControllerConfigs() {
	return _configUtil2.default.getAllConfigs().then(function () {
		var fogControllerConfigs = {
			ipAddress: _configUtil2.default.getConfigParam(_constants2.default.CONFIG.fog_controller_ip_address) || _config2.default.fogControllerIPAddress,
			port: _configUtil2.default.getConfigParam(_constants2.default.CONFIG.fog_controller_port) || _config2.default.fogControllerPort,
			protocol: _configUtil2.default.getConfigParam(_constants2.default.CONFIG.fog_controller_protocol) || _config2.default.fogControllerProtocol
		};
		return fogControllerConfigs;
	});
};

var authenticateUser = function authenticateUser(req, res, next) {
	getFogControllerConfigs().then(function (configs) {
		var url = configs.protocol + '://' + configs.ipAddress + ':' + configs.port + '/api/v2/user/authenticate/' + req.cookies.apwAccessToken;
		najax(url, { type: 'GET' }).success(function (result) {
			var resp = JSON.parse(result);

			if (resp.status == 'ok') {
				next();
			} else {
				res.redirect('/login');
			}
		}).error(function (result) {
			res.redirect('/login');
		});
	});
};

var loginPage = function loginPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("login/base", {
			title: 'Login to iotracks',
			metaDescription: "User login page for iotracks software",
			metaCacheControl: "",
			metaPragma: "",
			metaKeywords: "",
			metaAuthor: "iotracks, inc.",
			metaCopyright: "2016 iotracks, inc.",
			metaRobotDirective: "",
			linkCanonical: "https://iotracks.com/login",
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var logoutEndPoint = function logoutEndPoint(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("logout/base", {
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var userSignupPage = function userSignupPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("login/userSignup", {
			title: 'Signup for iotracks',
			metaDescription: "User signup page for iotracks software",
			metaCacheControl: "",
			metaPragma: "",
			metaKeywords: "",
			metaAuthor: "iotracks, inc.",
			metaCopyright: "2016 iotracks, inc.",
			metaRobotDirective: "",
			linkCanonical: "https://iotracks.com/signup",
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var updateProfilePage = function updateProfilePage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("account/updateProfile", {
			title: 'Update iotracks profile',
			metaDescription: "Update profile for iotracks user",
			metaCacheControl: "",
			metaPragma: "",
			metaKeywords: "",
			metaAuthor: "iotracks, inc.",
			metaCopyright: "2016 iotracks, inc.",
			metaRobotDirective: "",
			linkCanonical: "https://iotracks.com/profile/update",
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var resetUserPasswordPage = function resetUserPasswordPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("login/resetPassword", {
			title: 'Forgot password',
			metaDescription: "Password reset page for iotracks software",
			metaCacheControl: "",
			metaPragma: "",
			metaKeywords: "",
			metaAuthor: "iotracks, inc.",
			metaCopyright: "2016 iotracks, inc.",
			metaRobotDirective: "",
			linkCanonical: "https://iotracks.com/password/reset",
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var updateUserPasswordPage = function updateUserPasswordPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("account/updatePassword", {
			title: 'Change iotracks password',
			metaDescription: "Change password for iotracks software",
			metaCacheControl: "",
			metaPragma: "",
			metaKeywords: "",
			metaAuthor: "iotracks, inc.",
			metaCopyright: "2016 iotracks, inc.",
			metaRobotDirective: "",
			linkCanonical: "https://iotracks.com/password/change",
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var deleteUserAccountPage = function deleteUserAccountPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("account/deleteUserAccount", {
			title: 'Delete iotracks account',
			metaDescription: "Delete account for iotracks user",
			metaCacheControl: "",
			metaPragma: "",
			metaKeywords: "",
			metaAuthor: "iotracks, inc.",
			metaCopyright: "2016 iotracks, inc.",
			metaRobotDirective: "",
			linkCanonical: "https://iotracks.com/account/delete",
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var resendActivationEmailPage = function resendActivationEmailPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("login/resendActivationEmail", {
			title: 'Resend activation',
			metaDescription: "Resend activation email page for iotracks software",
			metaCacheControl: "",
			metaPragma: "",
			metaKeywords: "",
			metaAuthor: "iotracks, inc.",
			metaCopyright: "2016 iotracks, inc.",
			metaRobotDirective: "",
			linkCanonical: "https://iotracks.com/account/activate/resend",
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var activateAccountPage = function activateAccountPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("account/activateUserAccount", {
			title: 'Activate account',
			metaDescription: "Account activation page for iotracks software",
			metaCacheControl: "",
			metaPragma: "",
			metaKeywords: "",
			metaAuthor: "iotracks, inc.",
			metaCopyright: "2016 iotracks, inc.",
			metaRobotDirective: "",
			linkCanonical: "https://iotracks.com/account/activate",
			code: req.params.code,
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var buildPage = function buildPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("build/base", {
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var publishingPage = function publishingPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("publish/base", {
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};

var fogPage = function fogPage(req, res) {
	getFogControllerConfigs().then(function (configs) {
		res.render("fog/base", {
			fogControllerUrl: configs.protocol + '://' + configs.ipAddress + ':' + configs.port
		});
	});
};
var accountPage = function accountPage(req, res) {
	res.render("account/base");
};

exports.default = {
	authenticateUser: authenticateUser,
	activateAccountPage: activateAccountPage,
	loginPage: loginPage,
	logoutEndPoint: logoutEndPoint,
	resetUserPasswordPage: resetUserPasswordPage,
	resendActivationEmailPage: resendActivationEmailPage,
	userSignupPage: userSignupPage,
	buildPage: buildPage,
	publishingPage: publishingPage,
	fogPage: fogPage,
	accountPage: accountPage,
	updateProfilePage: updateProfilePage,
	updateUserPasswordPage: updateUserPasswordPage,
	deleteUserAccountPage: deleteUserAccountPage
};